==> rayasdk-1.1.0.dev1.tar.gz: rayasdk-1.1.0.dev1/rayasdk/utils.py <==
import os
import urllib
import json
import tarfile
import progressbar
from simple_file_checksum import get_checksum

from rayasdk.messages import *
from rayasdk.constants import *
from rayasdk.logger import *
from rayasdk.container_handlers.docker_handler import *


class MyProgressBar:

    def __init__(self):
        self.pbar = None

    def __call__(self, block_num, block_size, total_size):
        if self.pbar is None:
            self.pbar = progressbar.ProgressBar(maxval=total_size)
            self.pbar.start()

        downloaded = block_num * block_size
        if downloaded < total_size:
            self.pbar.update(downloaded)
        else:
            self.pbar.finish()


def run_simulator_bridge():
    return launch_command()


def download_simulator(response=None):
    if response is not None:
        # Get parameters from VCS API
        for component in response:
            if component['name'] == 'Unity':
                response = component
        sim_url = response["link"]
        garysim_sha256 = response["checksum"]
        version = response["versionId"]
    else:
        # Set parameters from local constants file
        sim_url = GARYSIM_URL
        garysim_sha256 = GARYSIM_SHA256
        version = GARYSIM_VERSION
    log_info(f'Downloading Ra-Ya simulator v{version}...')
    sim_tarpath = f'{SIMS_HOME}/simulator_{version}.tar.gz'

    try:
        urllib.request.urlretrieve(sim_url, sim_tarpath, MyProgressBar())
    except urllib.error.HTTPError:
        log_error(f'Download error, the url {sim_url} does not exist.')
        return False

    log_info(f'Checking downloaded file...')
    try:
        sha256 = get_checksum(sim_tarpath, algorithm="SHA256")
    except FileNotFoundError:
        log_error('Download error, try again.')
        return False
    if garysim_sha256 != sha256:
        log_error('Download error, try again.')
        return False

    log_info(f'Extracting...')
    simtar = tarfile.open(sim_tarpath)
    simtar.extractall(SIMS_HOME)
    os.remove(sim_tarpath)
    return True


def is_snake_case(s: str):
    """
    Returns True if s is in snake case, False otherwise.
    """
    if not s.islower():
        return False
    if '__' in s:
        return False
    if s.startswith('_') or s.endswith('_'):
        return False
    if not all(c.isalpha() or c.isdigit() or c == '_' for c in s):
        return False
    return True


def validate_app_id_and_folder_name(app_id: str):
    APP_MAIN_FOLDER_NAME = os.path.basename(os.path.normpath(CURRENT_PATH))
    if APP_MAIN_FOLDER_NAME != app_id:
        raise Exception('The app_id and the folder name are different')
    if not is_snake_case(app_id):
        raise Exception('The app_id have to be in snake case format')
    return True


def open_connection_file():
    try:
        with open(CONNECTION_SETTINGS_PATH, 'r', encoding='utf-8') as f:
            connection_settings = json.load(f)
        return connection_settings
    except OSError:
        raise Exception((f'the file "{CONNECTION_SETTINGS_FILE}" was not found, '
                'run \'rayasdk connect\''))

==> rayasdk-1.1.1.dev0.tar.gz: rayasdk-1.1.1.dev0/rayasdk/utils.py <==
import os
import json
import progressbar

import rayasdk.constants as constants
from rayasdk.messages import *
from rayasdk.container_handlers.docker_handler import DockerHandler


class MyProgressBar:

    def __init__(self):
        self.pbar = None


    def __call__(self, block_num, block_size, total_size):
        if self.pbar is None:
            self.pbar = progressbar.ProgressBar(maxval=total_size)
            self.pbar.start()

        downloaded = block_num * block_size
        if downloaded < total_size:
            self.pbar.update(downloaded)
        else:
            self.pbar.finish()


def run_simulator_bridge():
    return DockerHandler().launch_command()


def is_snake_case(s: str):
    """
    Returns True if s is in snake case, False otherwise.
    """
    if not s.islower():
        return False
    if '__' in s:
        return False
    if s.startswith('_') or s.endswith('_'):
        return False
    if not all(c.isalpha() or c.isdigit() or c == '_' for c in s):
        return False
    return True


def validate_app_id_and_folder_name(app_id: str):
    APP_MAIN_FOLDER_NAME = os.path.basename(
        os.path.normpath(constants.CURRENT_PATH))
    if APP_MAIN_FOLDER_NAME != app_id:
        raise Exception('The app_id and the folder name are different')
    if not is_snake_case(app_id):
        raise Exception('The app_id have to be in snake case format')
    return True


def open_connection_file():
    try:
        with open(
                file=constants.CONNECTION_SETTINGS_PATH,
                mode='r',
                encoding='utf-8'
            ) as f:
            connection_settings = json.load(f)
        return connection_settings
    except OSError:
        raise Exception(
            (f'the file "{constants.CONNECTION_SETTINGS_FILE}" was not found, '
             'run \'rayasdk connect\''))


def change_directory(path):
    if os.path.isabs(path):
        os.chdir(path)
        return path
    else:
        abs_path = os.path.join(os.getcwd(), path)
        os.chdir(abs_path)
        return abs_path
